@@ -471,7 +471,9 @@ static int child_process(entry * e, char **jobenv) {
 				if (MailCmd[0] == '\0') {
 					int len;
 
-					len = snprintf(mailcmd, sizeof mailcmd, MAILFMT, MAILARG);
+					/* Use empty envelope address with default mailfrom */
+					len = snprintf(mailcmd, sizeof mailcmd, MAILFMT, MAILARG,
+							mailfrom == e->pwd->pw_name ? "<>" : mailfrom);
 					if (len < 0) {
 						fprintf(stderr, "mailcmd snprintf failed\n");
 						(void) _exit(ERROR_EXIT);
@@ -577,7 +579,7 @@ static int child_process(entry * e, char **jobenv) {
 			if (mail && e->flags & MAIL_WHEN_ERR) {
 				int jobstatus = -1;
 				if (jobpid > 0) {
-					while (waitpid(jobpid, &jobstatus, WNOHANG) == -1) {
+					while (waitpid(jobpid, &jobstatus, 0) == -1) {
 						if (errno == EINTR) continue;
 						log_it("CRON", getpid(), "error", "invalid job pid", errno);
 						break;
