@@ -18,9 +18,14 @@
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
+
+#ifndef CRONIE_MACROS_H
+#define CRONIE_MACROS_H
+
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
+
 	/* these are really immutable, and are
 	 *   defined for symbolic convenience only
 	 * TRUE, FALSE, and ERR must be distinct
@@ -53,6 +58,10 @@
 #define	MAX_UNAME	256	/* max length of username  */
 #define	ROOT_UID	0	/* don't change this, it really must be root */
 #define	ROOT_USER	"root"	/* ditto */
+#define MAX_USER_ENVS	1000	/* maximum environment variables in user's crontab */
+#define MAX_USER_ENTRIES 10000	/* maximum crontab entries in user's crontab */
+#define MAX_GARBAGE	32768	/* max num of chars of comments and whitespaces between entries */
+#define MAX_CLOSE_FD	10000	/* max fd num to close when spawning a child process */
 
 				/* NOTE: these correspond to DebugFlagNames,
 				 *	defined below.
@@ -82,10 +91,10 @@
 #if DEBUGGING
 # define Debug(mask, message) \
 			if ((DebugFlags & (mask)) != 0) \
-				printf message;
+				printf message
 #else /* !DEBUGGING */
 # define Debug(mask, message) \
-			;
+			()
 #endif /* DEBUGGING */
 
 #define	MkUpper(ch)	(islower(ch) ? toupper(ch) : ch)
@@ -121,12 +130,18 @@
 #define	LAST_DOW	7
 #define	DOW_COUNT	(LAST_DOW - FIRST_DOW + 1)
 
+#define TMAX(a,b) ((a)>(b)?(a):(b))
+#define TMIN(a,b) ((a)<(b)?(a):(b))
+
 /*
  * Because crontab/at files may be owned by their respective users we
  * take extreme care in opening them.  If the OS lacks the O_NOFOLLOW
  * we will just have to live without it.  In order for this to be an
  * issue an attacker would have to subvert group CRON_GROUP.
  */
+#include <fcntl.h>
 #ifndef O_NOFOLLOW
 #define O_NOFOLLOW	0
 #endif
+
+#endif /* CRONIE_MACROS_H */
