@@ -30,7 +30,8 @@
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <sys/param.h>
 
 #if !defined(OpenBSD) || OpenBSD < 200105
@@ -40,10 +41,13 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "funcs.h"
+#include "globals.h"
+
 struct passwd *
 pw_dup(const struct passwd *pw) {
 	char		*cp;
-	size_t		 nsize=0, psize=0, gsize=0, dsize=0, ssize=0, total=0;
+	size_t		 nsize=0, psize=0, gsize=0, dsize=0, ssize=0, total;
 	struct passwd	*newpw;
 
 	/* Allocate in one big chunk for easy freeing */
@@ -117,6 +121,7 @@ pw_dup(const struct passwd *pw) {
 		cp += ssize;
 	}
 
+	/* cppcheck-suppress[memleak symbolName=cp] memory originally pointed to by cp returned via newpw */
 	return (newpw);
 }
 
